@@ -15,7 +15,7 @@ class Model(BaseModel):
     class Config:
         arbitrary_types_allowed = True
 
-    _model_exists = root_validator(check_model_exists, allow_reuse=True)
+    # _model_exists = root_validator(check_model_exists, allow_reuse=True)
     _get_model_type = root_validator(fetch_model_type, allow_reuse=True)
 
 
