@@ -6,6 +6,7 @@ from captur_ml_sdk.dtypes.interfaces.MLGateway.MLPredictRequest import ModelPred
 from captur_ml_sdk.dtypes.interfaces.MLGateway.MLLivePredictRequest import ModelLivePredictRequest
 from captur_ml_sdk.dtypes.interfaces.MLGateway.MLTrainRequest import ModelTrainRequest
 from captur_ml_sdk.dtypes.interfaces.MLGateway.MLEvalRequest import ModelEvaluateRequest
+from captur_ml_sdk.dtypes.interfaces.MLGateway.MLRegisterModel import ModelRegisterRequest
 
 
 class GatewayRequest(BaseModel):
@@ -14,15 +15,17 @@ class GatewayRequest(BaseModel):
     live_predict: Optional[ModelLivePredictRequest]
     train: Optional[ModelTrainRequest]
     evaluate: Optional[ModelEvaluateRequest]
+    register_model: Optional[ModelRegisterRequest]
 
     @root_validator
     def request_must_have_predict_live_predict_train_or_evaluate(cls, values):
         if not values.get("predict") \
                 and not values.get("live_predict") \
                 and not values.get("train") \
-                and not values.get("evaluate"):
+                and not values.get("evaluate") \
+                and not values.get("register_model"):
             raise ValueError(
-                "Request must include either 'predict', 'live_predict', 'train' or 'evaluate'")
+                "Request must include either 'predict', 'live_predict', 'train', 'evaluate' or 'register_model'")
 
         return values
 
