@@ -5,13 +5,13 @@ from pydantic import (
 
 from typing import Optional, List
 
-from captur_ml_sdk.dtypes.generics import Image, Meta
+from captur_ml_sdk.dtypes.generics import Image, PredictMeta
 from captur_ml_sdk.dtypes.interfaces.validators import check_images_or_imagefile_has_data
 
 
 class OfflinePreRunEventData(BaseModel):
     request_id: str
-    meta: Optional[Meta]
+    meta: Optional[PredictMeta]
     images: Optional[List[Image]]
     imagesfile: Optional[str]
     model_name: str
